;; This Source Code Form is subject to the terms of the Mozilla Public
;; License, v. 2.0. If a copy of the MPL was not distributed with this
;; file, You can obtain one at http://mozilla.org/MPL/2.0/.
;;
;; Copyright (c) 2015-2016 Andrey Antukh <niwi@niwi.nz>

(ns uxbox.builtins.colors
  (:require [uxbox.util.uuid :as uuid]
            [uxbox.util.data :refer (index-by)]))

(def collections-list
  [{:name "Grays"
    :id #uuid "00000000-0000-0000-0000-000000000001"
    :created-at 1
    :type :builtin
    :colors #{"#D3D3D3"
              "#C0C0C0"
              "#A9A9A9"
              "#DCDCDC"
              "#808080"
              "#696969"
              "#000000"}}

   {:name "Silver"
    :id #uuid "00000000-0000-0000-0000-000000000002"
    :type :builtin
    :created-at 2
    :colors #{"#D3D3D3"
              "#C0C0C0"
              "#A9A9A9"
              "#808080"}}

   {:name "Blues"
    :id #uuid "00000000-0000-0000-0000-000000000003"
    :type :builtin
    :created-at 3
    :colors #{"#F0F8FF"
              "#E6E6FA"
              "#B0E0E6"
              "#ADD8E6"
              "#87CEFA"
              "#87CEEB"
              "#00BFFF"
              "#B0C4DE"
              "#1E90FF"
              "#6495ED"
              "#4682B4"
              "#5F9EA0"
              "#7B68EE"
              "#6A5ACD"
              "#483D8B"
              "#4169E1"
              "#0000FF"
              "#0000CD"
              "#00008B"
              "#000080"
              "#191970"
              "#8A2BE2"
              "#4B0082"}}

   {:name "UXBOX"
    :id #uuid "00000000-0000-0000-0000-000000000004"
    :type :builtin
    :created-at 4
    :colors #{"#78dbbe"
              "#b6dd75"
              "#a599c6"
              "#e6a16f"
              "#de4762"
              "#59b9e2"
              "#ffffff"
              "#000000"
              "#90969d"
              "#2C2C2C"
              "#3d3f40"
              "#181818"
              "#a9adaf"
              "#808386"
              "#4a4e52"
              "#e0e6e9"
              "#8d9496"
              "#4e4f50"
              "#878c8e"}}

   ;; https://github.com/redpik/social-media-colors
   {:name "Social"
    :id #uuid "00000000-0000-0000-0000-000000000005"
    :type :builtin
    :created-at 5
    :colors #{"#3B5998" ;; FACEBOOK
              "#D8DFEA"
              "#F03D25"
              ;; TWITTER
              "#55ACEE"
              ;; WHATSAPP
              "#00e676"
              "#1ebea5"
              ;; GOOGLE+
              "#dd4b39"
              "#427FED"
              ;; LINKEDIN
              "#0976B4"
              ;; PINTEREST
              "#cd1d1f"
              ;; FOURSQUARE
              "#0072b1"
              "#0cbadf"
              "#8fd400"
              "#ff7900"
              ;; YOUTUBE
              "#CC181E"
              "#110f10"
              ;; INSTAGRAM
              "#3F729B"
              ;; FLICKR
              "#0063dd"
              "#ff0085"
              ;; VIMEO
              "#1ab7ea"
              "#162221"
              ;; TUMBLR
              "#35465d"
              ;; STUMBLEUPON
              "#EB4924"
              "#333333"
              ;; MYSPACE
              "#008DDE"
              "#313131"
              "#1D1D1D"
              ;; DRIBBBLE
              "#ea4c89"
              "#444444"
              "#8aba56"
              ;; DAILYMOTION
              "#0079b8"
              "#fed417"
              ;; DELICIOUS
              "#3274D0"
              "#D3D2D2"
              "#222222"
              "#0B79E5"
              ;; SOUNDCLOUD
              "#FF3D00"
              ;; GITHUB
              "#171515"
              "#4183c4"
              ;; QUORA
              "#BC2016"
              ;; BEHANCE
              "#1769FF"
              "#242424"
              ;; VINE
              "#00B489"
              ;; VKONTAKTE
              "#587fa4"
              "#e9edf1"
              ;; REDDIT
              "#F64720"
              "#CEE3F8"
              ;; DROPBOX
              "#007ee5"
              "#7B8994"
              "#47525D"
              "#3D464D"}}

   ;; https://github.com/twbs/bootstrap
   {:name "Bootstrap"
    :id #uuid "00000000-0000-0000-0000-000000000006"
    :type :builtin
    :created-at 6
    :colors #{"#ffffff"
              "#f8f9fa"
              "#e9ecef"
              "#dee2e6"
              "#ced4da"
              "#adb5bd"
              "#6c757d"
              "#495057"
              "#343a40"
              "#212529"
              "#000000"
              "#007bff"
              "#6610f2"
              "#6f42c1"
              "#e83e8c"
              "#dc3545"
              "#fd7e14"
              "#ffc107"
              "#28a745"
              "#20c997"
              "#17a2b8"}}

   ;; https://github.com/shuhei/material-colors
   {:name "Material Design"
    :id #uuid "00000000-0000-0000-0000-000000000007"
    :type :builtin
    :created-at 7
    :colors #{"#ffebee"
              "#ffcdd2"
              "#ef9a9a"
              "#e57373"
              "#ef5350"
              "#f44336"
              "#e53935"
              "#d32f2f"
              "#c62828"
              "#b71c1c"
              "#ff8a80"
              "#ff5252"
              "#ff1744"
              "#d50000"
              "#fce4ec"
              "#f8bbd0"
              "#f48fb1"
              "#f06292"
              "#ec407a"
              "#e91e63"
              "#d81b60"
              "#c2185b"
              "#ad1457"
              "#880e4f"
              "#ff80ab"
              "#ff4081"
              "#f50057"
              "#c51162"
              "#f3e5f5"
              "#e1bee7"
              "#ce93d8"
              "#ba68c8"
              "#ab47bc"
              "#9c27b0"
              "#8e24aa"
              "#7b1fa2"
              "#6a1b9a"
              "#4a148c"
              "#ea80fc"
              "#e040fb"
              "#d500f9"
              "#aa00ff"
              "#ede7f6"
              "#d1c4e9"
              "#b39ddb"
              "#9575cd"
              "#7e57c2"
              "#673ab7"
              "#5e35b1"
              "#512da8"
              "#4527a0"
              "#311b92"
              "#b388ff"
              "#7c4dff"
              "#651fff"
              "#6200ea"
              "#e8eaf6"
              "#c5cae9"
              "#9fa8da"
              "#7986cb"
              "#5c6bc0"
              "#3f51b5"
              "#3949ab"
              "#303f9f"
              "#283593"
              "#1a237e"
              "#8c9eff"
              "#536dfe"
              "#3d5afe"
              "#304ffe"
              "#e3f2fd"
              "#bbdefb"
              "#90caf9"
              "#64b5f6"
              "#42a5f5"
              "#2196f3"
              "#1e88e5"
              "#1976d2"
              "#1565c0"
              "#0d47a1"
              "#82b1ff"
              "#448aff"
              "#2979ff"
              "#2962ff"
              "#e1f5fe"
              "#b3e5fc"
              "#81d4fa"
              "#4fc3f7"
              "#29b6f6"
              "#03a9f4"
              "#039be5"
              "#0288d1"
              "#0277bd"
              "#01579b"
              "#80d8ff"
              "#40c4ff"
              "#00b0ff"
              "#0091ea"
              "#e0f7fa"
              "#b2ebf2"
              "#80deea"
              "#4dd0e1"
              "#26c6da"
              "#00bcd4"
              "#00acc1"
              "#0097a7"
              "#00838f"
              "#006064"
              "#84ffff"
              "#18ffff"
              "#00e5ff"
              "#00b8d4"
              "#e0f2f1"
              "#b2dfdb"
              "#80cbc4"
              "#4db6ac"
              "#26a69a"
              "#009688"
              "#00897b"
              "#00796b"
              "#00695c"
              "#004d40"
              "#a7ffeb"
              "#64ffda"
              "#1de9b6"
              "#00bfa5"
              "#e8f5e9"
              "#c8e6c9"
              "#a5d6a7"
              "#81c784"
              "#66bb6a"
              "#4caf50"
              "#43a047"
              "#388e3c"
              "#2e7d32"
              "#1b5e20"
              "#b9f6ca"
              "#69f0ae"
              "#00e676"
              "#00c853"
              "#f1f8e9"
              "#dcedc8"
              "#c5e1a5"
              "#aed581"
              "#9ccc65"
              "#8bc34a"
              "#7cb342"
              "#689f38"
              "#558b2f"
              "#33691e"
              "#ccff90"
              "#b2ff59"
              "#76ff03"
              "#64dd17"
              "#f9fbe7"
              "#f0f4c3"
              "#e6ee9c"
              "#dce775"
              "#d4e157"
              "#cddc39"
              "#c0ca33"
              "#afb42b"
              "#9e9d24"
              "#827717"
              "#f4ff81"
              "#eeff41"
              "#c6ff00"
              "#aeea00"
              "#fffde7"
              "#fff9c4"
              "#fff59d"
              "#fff176"
              "#ffee58"
              "#ffeb3b"
              "#fdd835"
              "#fbc02d"
              "#f9a825"
              "#f57f17"
              "#ffff8d"
              "#ffff00"
              "#ffea00"
              "#ffd600"
              "#fff8e1"
              "#ffecb3"
              "#ffe082"
              "#ffd54f"
              "#ffca28"
              "#ffc107"
              "#ffb300"
              "#ffa000"
              "#ff8f00"
              "#ff6f00"
              "#ffe57f"
              "#ffd740"
              "#ffc400"
              "#ffab00"
              "#fff3e0"
              "#ffe0b2"
              "#ffcc80"
              "#ffb74d"
              "#ffa726"
              "#ff9800"
              "#fb8c00"
              "#f57c00"
              "#ef6c00"
              "#e65100"
              "#ffd180"
              "#ffab40"
              "#ff9100"
              "#ff6d00"
              "#fbe9e7"
              "#ffccbc"
              "#ffab91"
              "#ff8a65"
              "#ff7043"
              "#ff5722"
              "#f4511e"
              "#e64a19"
              "#d84315"
              "#bf360c"
              "#ff9e80"
              "#ff6e40"
              "#ff3d00"
              "#dd2c00"
              "#efebe9"
              "#d7ccc8"
              "#bcaaa4"
              "#a1887f"
              "#8d6e63"
              "#795548"
              "#6d4c41"
              "#5d4037"
              "#4e342e"
              "#3e2723"
              "#fafafa"
              "#f5f5f5"
              "#eeeeee"
              "#e0e0e0"
              "#bdbdbd"
              "#9e9e9e"
              "#757575"
              "#616161"
              "#424242"
              "#212121"
              "#eceff1"
              "#cfd8dc"
              "#b0bec5"
              "#90a4ae"
              "#78909c"
              "#607d8b"
              "#546e7a"
              "#455a64"
              "#37474f"
              "#263238"
              "#000000"
              "#ffffff"}}])

(def collections
  (index-by collections-list :id))
